@@ -16,7 +16,6 @@
 #define KEY 12
 #define REST 13
 #define TUPLE 14
-#define TIED_NOTE 15
 /* CHORD replaced by CHORDON and CHORDOFF */
 #define NOTE 16
 #define NONOTE 17
@@ -40,12 +39,14 @@
 #define CHORDOFF 35
 #define SLUR_TIE 36
 #define NEWLINE 37
+#define TNOTE 38
 
 /* broken rhythm */
-#define LT 38
-#define GT 39
+#define LT 39
+#define GT 40
 
-#define DYNAMIC 40
+#define DYNAMIC 41
+#define LINENUM 42
 
 /* note decorations */
 #define DECSIZE 8
@@ -58,3 +59,10 @@ static char decorations[] = ".H~RuvML";
 #define BOWDOWN 5
 #define TENUTO 6
 #define LOUD 7
+
+struct vstring {
+int len;
+int limit;
+char* st;
+};
+
