@@ -34,6 +34,7 @@
  * mf_sec2ticks routine corrected.
  * private functions declared 'static' at start of file to stop gcc
  * generating error messages.
+ * modified 23/6/98 mferror made more helpful.
  */
 #include "midifile.h"
 #define NULLFUNC 0
@@ -461,9 +462,12 @@ read16bit()
 mferror(s)
 char *s;
 {
-  if ( Mf_error )
+  if ( Mf_error ) {
     (*Mf_error)(s);
-  exit(1);
+  } else {
+    printf("MIDI read/write error : %s\n", s);
+    exit(1);
+  };
 }
 
 /* The code below allows collection of a system exclusive message of */
