@@ -11,7 +11,6 @@
 /* Wil Macaulay (wil@syndesis.com) */ 
 
 
-#define MAXLINE 200
 #define TAB 9
 #include "abc.h"
 #include <stdio.h>
@@ -29,32 +28,104 @@
 int lineno;
 int parsing, slur;
 int inhead, inbody;
+int parserinchord;
+int chorddecorators[DECSIZE];
 char* index();
 
+int* checkmalloc(bytes)
+/* malloc with error checking */
+int bytes;
+{
+  int *p;
+  char* malloc();
+
+  p = (int*) malloc(bytes);
+  if (p == NULL) {
+    printf("Out of memory error - malloc failed!\n");
+    exit(0);
+  };
+  return (p);
+}
+
+initvstring(s)
+struct vstring *s;
+{
+  s->len = 0;
+  s->limit = 40;
+  s->st = (char*) checkmalloc(s->limit + 1);
+  *(s->st) = '\0';
+}
+
+extendvstring(s)
+struct vstring *s;
+{
+  char* p;
+
+  s->limit = s->limit * 2;
+  p = (char*) checkmalloc(s->limit + 1);
+  strcpy(p, s->st);
+  free(s->st);
+  s->st = p;
+}
+
+addch(ch, s)
+char ch;
+struct vstring *s;
+{
+  if (s->len >= s->limit) {
+    extendvstring(s);
+  };
+  *(s->st+s->len) = ch;
+  *(s->st+(s->len)+1) = '\0';
+  s->len = (s->len) + 1;
+}
+
+addtext(text, s)
+char* text;
+struct vstring *s;
+{
+  int newlen;
+
+  newlen = s->len + strlen(text);
+  while (newlen >= s->limit) {
+    extendvstring(s);
+  };
+  strcpy(s->st+s->len, text);
+  s->len = newlen;
+}
+
+clearvstring(s)
+struct vstring *s;
+{
+  *(s->st) = '\0';
+  s->len = 0;
+}
+
 parseron()
 {
   parsing = 1;
   slur = 0;
-};
+}
 
 parseroff()
 {
   parsing = 0;
   slur = 0;
-};
+}
 
 skipspace(p)
 char **p;
 {
   /* skip space and tab */
   while(((int)**p == ' ') || ((int)**p == TAB)) *p = *p + 1;
-};
+}
 
 int readnumf(num)
 char *num;
 {
   int t;
   char* p;
+  extern char* index();
 
   p =num;
   if (index("0123456789", *p) == NULL) {
@@ -66,7 +137,7 @@ char *num;
     p = p + 1;
   };
   return (t);
-};
+}
 
 int readnump(p)
 char **p;
@@ -79,7 +150,7 @@ char **p;
     *p = *p + 1;
   };
   return (t);
-};
+}
 
 void readsig(a, b, sig)
 int *a, *b;
@@ -112,7 +183,7 @@ char **sig;
       t = t/2;
     };
   };
-};
+}
 
 void readlen(a, b, p)
 int *a, *b;
@@ -141,7 +212,7 @@ char **p;
       t = t/2;
     };
   };
-};
+}
 
 
 void parsekey(str)
@@ -282,6 +353,21 @@ char **s;
     decorators[t] = 1;
     *s = *s + 1;
   };
+  /*check for decorated chord */
+  if (**s == '[') {
+    event_warning("decorations applied to chord");
+    for (i = 0; i<DECSIZE; i++) chorddecorators[i] = decorators[i];
+    event_chordon();
+    parserinchord = 1;
+    *s = *s + 1;
+    skipspace(s);
+  };
+  if (parserinchord) {
+    /* inherit decorators */
+    for (i = 0; i<DECSIZE; i++) {
+      decorators[i] = decorators[i] | chorddecorators[i];
+    };
+  };
   /* read accidental */
   switch (**s) {
   case '_':
@@ -344,6 +430,7 @@ char* field;
   char* p;
   char* comment;
   int iscomment;
+  int i;
 
   comment = field;
   iscomment = 0;
@@ -356,7 +443,6 @@ char* field;
     comment = comment + 1;
   };
 
-  /* printf("parsing music line\n"); */
   p = field;
   skipspace(&p);
   while(*p != '\0') {
@@ -367,27 +453,29 @@ char* field;
       switch(*p) {
       case '+':
         event_chord();
+        parserinchord = 1 - parserinchord;
+        if (parserinchord == 0) {
+          for (i = 0; i<DECSIZE; i++) chorddecorators[i] = 0;
+        };
         p = p + 1;
         break;
       case '"':
         {
-          int i;
-          char gchord[MAXLINE];
+          struct vstring gchord;
    
           p = p + 1;
-          i = 0;
+          initvstring(&gchord);
           while ((*p != '"') && (*p != '\0')) {
-            gchord[i] = *p;
-            i = i + 1;
+            addch(*p, &gchord);
             p = p + 1;
           };
-          gchord[i] = '\0';
           if (*p == '\0') {
             event_error("Guitar chord name not properly closed");
           } else {
             p = p + 1;
           };
-          event_gchord(gchord);
+          event_gchord(gchord.st);
+          free(gchord.st);
           break;
         };
       case '|':
@@ -503,12 +591,15 @@ char* field;
           break;
         default:
           event_chordon();
+          parserinchord = 1;
           break;
         };
         break;
       case ']':
         p = p + 1;
         event_chordoff();
+        parserinchord = 0;
+        for (i = 0; i<DECSIZE; i++) chorddecorators[i] = 0;
         break;
       case 'z':
         {
@@ -579,26 +670,24 @@ char* field;
         break;
       case '!':
         {
-          int i;
-          char instruction[MAXLINE];
+          struct vstring instruction;
           char *s;
    
           p = p + 1;
           s = p;
-          i = 0;
+          initvstring(&instruction);
           while ((*p != '!') && (*p != '\0')) {
-            instruction[i] = *p;
-            i = i + 1;
+            addch(*p, &instruction);
             p = p + 1;
           };
-          instruction[i] = '\0';
           if (*p != '!') {
             p = s;
             event_lineend('!', 1);
           } else {
-            event_instruction(instruction);
+            event_instruction(instruction.st);
             p = p + 1;
           };
+          free(instruction.st);
         };
         break;
       case '*':
@@ -629,7 +718,7 @@ char* field;
   if (iscomment) {
     event_precomment(comment);
   };
-};
+}
 
 parse_tempo(place)
 char* place;
@@ -661,7 +750,7 @@ char* place;
   };
   skipspace(&p);
   event_tempo(readnumf(p), a, b, relative);
-};
+}
 
 parsefield(key, field)
 char key;
@@ -698,6 +787,7 @@ char* field;
       event_refno(x);
       inhead = 1;
       inbody = 0;
+      parserinchord = 0;
       break;
     };
   case 'K':
@@ -756,7 +846,7 @@ char* field;
   if (iscomment) {
     event_precomment(comment);  
   };
-};
+}
 
 readstr(out, in)
 char *out;
@@ -771,7 +861,7 @@ char **in;
     *in = *in + 1;
   };
   *p = '\0';
-};
+}
 
 event_precomment(s)
 char* s;
@@ -786,14 +876,14 @@ char* s;
   } else {
     event_comment(s);
   };
-};
+}
 
 parseline(line)
-char line[MAXLINE];
+char* line;
 {
   char *p, *q;
 
-  /* printf("parsing : %s\n", line);  */
+  /* printf("parsing : %s\n", line); */
   p = line;
   skipspace(&p);
   if (strlen(p) == 0) {
@@ -839,15 +929,16 @@ char line[MAXLINE];
       event_text(p);
     };
   };
-};
+}
 
 parsefile(name)
 char* name;
 {
   FILE *fp;
   int reading;
-  char line[MAXLINE];
-  int t, len;
+  struct vstring line;
+  /* char line[MAXLINE]; */
+  int t;
 
   /* printf("parsefile called %s\n", name); */
   fp = fopen(name, "r");
@@ -859,42 +950,36 @@ char* name;
   inbody = 0;
   parseroff();
   reading = 1;
-  len = 0;
+  line.limit = 4;
+  initvstring(&line);
   lineno = 1;
   while (reading) {
     t = getc(fp);
     if (t == EOF) {
       reading = 0;
-      if (len>0) {
-        line[len] = '\0';
-        parseline(line);
-        event_linebreak();
+      if (line.len>0) {
+        parseline(line.st);
         lineno = lineno + 1;
+        event_linebreak();
       };
     } else {
-      line[len] = (char) t;
-      len = len + 1;
-      if (len >= MAXLINE) {
-        event_error("Line too Long");
-        len = 0;
-      };
-      if (t == '\n') {
-        len = len - 1;
-        line[len] = '\0';
-        /* throw away carriage return in DOS input */
-        if ((len > 0) && ((int)line[len-1] == '\r')) {
-          line[len-1] ='\0';
+      /* throw away carriage return in DOS input */
+      if ((t != '\n') && (t != '\r')) {
+        addch((char) t, &line);
+      } else {
+        if (t == '\n') {
+          parseline(line.st);
+          clearvstring(&line);
+          lineno = lineno + 1;
+          event_linebreak();
         };
-        parseline(line);
-        event_linebreak();
-        lineno = lineno + 1;
-        len = 0;
       };
     };
   };
   fclose(fp);
   event_eof();
-};    
+  free(line.st);
+}    
 
 main(argc,argv)
 int argc;
@@ -908,7 +993,7 @@ char *argv[];
   } else {
     parsefile(filename);
   };
-};
+}
 
 /*
 int getline ()
