@@ -33,18 +33,7 @@ struct abctext{
 struct abctext* head;
 struct abctext* tail;
 
-char* checkmalloc(bytes)
-int bytes;
-{
-  char* p;
-
-  p = (char*) malloc(bytes);
-  if (p == NULL) {
-    printf("Out of memory error in malloc - aborting\n");
-    exit(0);
-  };
-  return(p);
-};
+char* checkmalloc();
 
 char* addstring(s)
 char* s;
@@ -54,7 +43,7 @@ char* s;
   p = checkmalloc(strlen(s)+1);
   strcpy(p, s);
   return(p);
-};
+}
 
 int purgespace(p)
 char* p;
@@ -72,7 +61,7 @@ char* p;
     *p = '\0';
   };
   return(blank);
-};
+}
 
 struct abctext* newabctext(t)
 enum abctype t;
@@ -106,7 +95,7 @@ enum abctype t;
   };
   inmusic = 1;
   return(p);
-};
+}
 
 freehead()
 {
@@ -122,7 +111,7 @@ freehead()
   if (head == NULL) {
     tail = NULL;
   };
-};
+}
 
 int abs(n)
 int n;
@@ -135,7 +124,7 @@ int n;
     r = -n;
   };
   return(r);
-};
+}
 
 int nextnotes()
 {
@@ -154,7 +143,7 @@ int nextnotes()
     };
   };
   return(n);
-};
+}
 
 setline(t)
 enum linestattype t;
@@ -166,7 +155,7 @@ enum linestattype t;
     printf("\\\n");
   };
   linestat = t;
-};
+}
 
 tryout(last)
 int last;
@@ -216,7 +205,7 @@ int last;
      };
     };
   };
-};
+}
 
 int getarg(option, argc, argv)
 char *option;
@@ -232,7 +221,7 @@ int argc;
     };
   };
   return (place);
-};
+}
 
 event_init(argc, argv, filename)
 int argc;
@@ -244,7 +233,7 @@ char** filename;
   extern int readnumf();
 
   if ((getarg("-h", argc, argv) != -1) || (argc < 2)) {
-    printf("abc2abc v 1.6.2\n");
+    printf("abc2abc v 1.6.3\n");
     printf("Usage: abc2abc <filename> [-s] [-n] [-b] [-r] [-e] [-t X] -u\n");
     printf("  -s for new spacing\n");
     printf("  -n for new linebreaks\n");
@@ -313,7 +302,7 @@ char** filename;
   tail = NULL;
   tmp[0] = '\0';
   totalnotes = 0;
-};
+}
 
 close_newabc()
 {
@@ -322,12 +311,12 @@ close_newabc()
     if (linestat == midmusic) setline(endmusicline);
     setline(fresh);
   };
-};
+}
 
 event_eof()
 {
   close_newabc();
-};
+}
 
 event_blankline()
 {
@@ -337,28 +326,28 @@ event_blankline()
   xinhead = 0;
   parseroff();
   blankline = 1;
-};
+}
 
 event_text(p)
 char *p;
 {
   sprintf(tmp+strlen(tmp),tmp, "%%%s", p);
   inmusic = 0;
-};
+}
 
 event_reserved(p)
 char p;
 {
   sprintf(tmp+strlen(tmp),tmp+strlen(tmp), "%c", p);
   inmusic = 0;
-};
+}
 
 event_tex(s)
 char *s;
 {
   sprintf(tmp+strlen(tmp),tmp+strlen(tmp),"%s", s);
   inmusic = 0;
-};
+}
 
 event_linebreak()
 {
@@ -374,11 +363,11 @@ event_linebreak()
     newabctext(bar);
     printf("\n");
   };
-};
+}
 
 event_musiclinebreak()
 {
-};
+}
 
 event_error(s)
 char *s;
@@ -386,7 +375,7 @@ char *s;
   if (echeck) {
    printf("\n%%Error : %s\n", s);
   };
-};
+}
 
 event_warning(s)
 char *s;
@@ -394,7 +383,7 @@ char *s;
   if (echeck) {
    printf("\n%%Warning : %s\n", s);
   };
-};
+}
 
 event_comment(s)
 char *s;
@@ -408,14 +397,14 @@ char *s;
   };
   sprintf(tmp+strlen(tmp),"%%%s", s);
   inmusic = 0;
-};
+}
 
 event_specific(p, s)
 char *p, *s;
 {
   sprintf(tmp+strlen(tmp),"%%%s %s", p, s);
   inmusic = 0;
-};
+}
 
 event_field(k, f)
 char k;
@@ -423,13 +412,13 @@ char *f;
 {
   sprintf(tmp+strlen(tmp),"%c:%s", k, f);
   inmusic = 0;
-};
+}
 
 event_words(p)
 char* p;
 {
   event_field('w', p);
-};
+}
 
 event_part(s)
 char* s;
@@ -439,7 +428,7 @@ char* s;
   };
   sprintf(tmp+strlen(tmp),"P:%s", s);
   inmusic = 0;
-};
+}
 
 event_voice(n, s)
 int n;
@@ -447,7 +436,7 @@ char *s;
 {
   sprintf(tmp+strlen(tmp),"V:%d %s", n, s);
   inmusic = 0;
-};
+}
 
 event_length(n)
 int n;
@@ -456,7 +445,7 @@ int n;
   unitlen.num = 1;
   unitlen.denom = n;
   inmusic = 0;
-};
+}
 
 event_refno(n)
 int n;
@@ -473,7 +462,7 @@ int n;
   barlen.num = 0;
   barlen.denom = 1;
   inmusic = 0;
-};
+}
 
 event_tempo(n, a, b, relative)
 int n, a, b;
@@ -489,7 +478,7 @@ int relative;
     };
   };
   inmusic = 0;
-};
+}
 
 event_timesig(n, m)
 int n, m;
@@ -509,7 +498,7 @@ int n, m;
   };
   barend = n/breakpoint.num;
   inmusic = 0;
-};
+}
 
 
 setmap(sf, map)
@@ -535,7 +524,7 @@ int map[7];
   if (sf <= -5) map['g'-'a'] = -1;
   if (sf <= -6) map['c'-'a'] = -1;
   if (sf <= -7) map['f'-'a'] = -1;
-};
+}
 
 event_key(sharps, s, minor, modmap, modmul)
 int sharps;
@@ -568,7 +557,7 @@ int modmul[7];
     sprintf(tmp+strlen(tmp),"K:%s", keys[newkey+5]);
   };
   inmusic = 0;
-};
+}
 
 start_tune()
 {
@@ -593,7 +582,7 @@ start_tune()
       unitlen.denom = 8;
     };
   };
-};
+}
 
 printlen(a, b)
 int a, b;
@@ -604,7 +593,7 @@ int a, b;
   if (b != 1) {
     sprintf(tmp+strlen(tmp),"/%d", b);
   };
-};
+}
 
 event_rest(n,m)
 int n, m;
@@ -622,7 +611,7 @@ int n, m;
   if (tuplenotes != 0) {
     event_error("Rest not allowed in tuple");
   };
-};
+}
 
 event_bar(type)
 int type;
@@ -701,36 +690,36 @@ int type;
   barno = barno + 1;
   count.num = 0;
   count.denom = 1;
-};
+}
 
 event_space()
 {
   if (!newspacing) {
     sprintf(tmp+strlen(tmp)," ");
   };
-};
+}
 
 event_graceon()
 {
   sprintf(tmp+strlen(tmp),"{");
   ingrace = 1;
-};
+}
 
 event_graceoff()
 {
   sprintf(tmp+strlen(tmp),"}");
   ingrace = 0;
-};
+}
 
 event_rep1()
 {
   sprintf(tmp+strlen(tmp)," [1");
-};
+}
 
 event_rep2()
 {
   sprintf(tmp+strlen(tmp)," [2");
-};
+}
 
 event_broken(type, n)
 int type, n;
@@ -742,7 +731,7 @@ int type, n;
   } else {
     for (i=0; i<n; i++) sprintf(tmp+strlen(tmp),"<");
   };
-};
+}
 
 event_tuple(n, q, r)
 int n, q, r;
@@ -774,7 +763,7 @@ int n, q, r;
       };
     };
   };
-};
+}
 
 event_chord()
 {
@@ -790,7 +779,7 @@ event_chord()
   inmusic = 1;
   inchord = 1 - inchord;
   chordcount = 0;
-};
+}
 
 event_chordon()
 {
@@ -798,14 +787,14 @@ event_chordon()
   inmusic = 1;
   inchord = 1;
   chordcount = 0;
-};
+}
 
 event_chordoff()
 {
   sprintf(tmp+strlen(tmp),"]");
   inmusic = 1;
   inchord = 0;
-};
+}
 
 splitstring(s, sep, handler)
 char* s;
@@ -831,7 +820,7 @@ void (*handler)();
     };
     (*handler)(out);
   };
-};
+}
 
 void event_handle_gchord(s)
 char* s;
@@ -898,19 +887,19 @@ char* s;
     };
   };
   sprintf(tmp+strlen(tmp),"\"%s\"", newchord);
-};
+}
 
 event_gchord(s)
 char* s;
 {
   splitstring(s, ';', event_handle_gchord);
-};
+}
 
 event_instruction(s)
 char* s;
 {
   sprintf(tmp+strlen(tmp),"!%s!", s);
-};
+}
 
 event_slur(t)
 int t;
@@ -924,24 +913,24 @@ int t;
   } else {
     sprintf(tmp+strlen(tmp),"s");
   };
-};
+}
 
 event_sluron(t)
 int t;
 {
   sprintf(tmp+strlen(tmp),"(");
-};
+}
 
 event_sluroff(t)
 int t;
 {
   sprintf(tmp+strlen(tmp),")");
-};
+}
 
 event_tie()
 {
   sprintf(tmp+strlen(tmp),"-");
-};
+}
 
 event_lineend(ch, n)
 char ch;
@@ -954,7 +943,7 @@ int n;
       sprintf(tmp+strlen(tmp),"%c", ch);
     };
   };
-};
+}
 
 event_note(decorators, xaccidental, xmult, xnote, xoctave, n, m)
 int decorators[DECSIZE];
@@ -1067,7 +1056,7 @@ int xoctave, n, m;
       sprintf(tmp+strlen(tmp)," ");
     };
   };
-};
+}
 
 reduce(a, b)
 int *a, *b;
@@ -1089,12 +1078,12 @@ int *a, *b;
   };
   *a = *a/n;
   *b = *b/n;
-};
+}
 
 addunits(n, m)
 {
   count.num = n*count.denom + count.num*(m*unitlen.denom);
   count.denom = (m*unitlen.denom)*count.denom;
   reduce(&count.num, &count.denom);
-};
+}
 
